package com.example.service;

import com.azure.data.appconfiguration.ConfigurationClient;
import com.azure.data.appconfiguration.ConfigurationClientBuilder;
import com.azure.data.appconfiguration.models.SettingSelector;
import org.junit.Before;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public class AzureAppConfigServiceTest {

    private static final Logger LOGGER = LoggerFactory.getLogger(AzureAppConfigServiceTest.class);
    AzureAppConfigService azureAppConfigService;

    @Before
    public void setUp() {
        String app_configuration_connection_string = System.getenv("APP_CONFIGURATION_CONNECTION_STRING");
        ConfigurationClient configurationClient = new ConfigurationClientBuilder().connectionString(app_configuration_connection_string).buildClient();
        azureAppConfigService = new AzureAppConfigService(configurationClient, new SettingSelector());
    }

    @Test
    public void getValueByKey() {
        String valueByKey = azureAppConfigService.getValueByKey("config.message");
        LOGGER.info(valueByKey);
        assertNotNull(valueByKey);
        assertEquals("This is Azure App Config", valueByKey);
    }

    @Test
    public void writeValueByKey() {
        String writeValueByKey = azureAppConfigService.writeValueByKey("config.dataSource", "Data Source URL");
        LOGGER.info(writeValueByKey);
        assertNotNull(writeValueByKey);
        assertEquals("Data Source URL", writeValueByKey);
    }

    @Test
    public void readAllKeyValue() {
        long count = azureAppConfigService.readAllKeyValue().stream().count();
        assertEquals(3, count);
    }

    @Test
    public void deleteValueByKey() {
        String valueByKey = azureAppConfigService.deleteValueByKey("config.dataSource");
        LOGGER.info(valueByKey);
        assertNotNull(valueByKey);
        assertEquals("Data Source URL", valueByKey);
    }

    @Test
    public void azureAppConfiguration() {
    }
}